// Licensed to LinDB under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. LinDB licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package fileutil

import (
	"bytes"
	"os"
	"path/filepath"
	"testing"

	"github.com/stretchr/testify/assert"
)

func TestRead(t *testing.T) {
	filename := filepath.Join(t.TempDir(), "testdata")
	file, err := os.Create(filename)
	assert.NoError(t, err)
	content := "abc123"
	_, err = file.WriteString(content)
	assert.NoError(t, err)
	assert.NoError(t, file.Close())

	file, err = os.Open(filename)
	assert.NoError(t, err)
	bys, err := Map(file)
	assert.NoError(t, err)
	assert.Equal(t, []byte(content), bys)
	assert.NoError(t, Unmap(file, bys))
}

func TestRWMap(t *testing.T) {
	var content = []byte("12345")
	var size = 1024
	filename := filepath.Join(t.TempDir(), "testdata")
	f, err := os.OpenFile(filename, os.O_CREATE|os.O_RDWR, 0644)
	assert.NoError(t, err)
	assert.NotNil(t, f)
	mapBytes, err := RWMap(f, size)
	assert.NoError(t, err)
	if Unmap(f, nil) != nil {
		t.Error("unmap nil returns not nil")
	}

	buffer := bytes.NewBuffer(mapBytes[:0])

	_, err = buffer.Write(content)
	assert.NoError(t, err)

	err = Sync(mapBytes)
	assert.NoError(t, err)

	if Unmap(f, mapBytes) != nil {
		t.Errorf("unmap mapBytes with error: %v", err)
	}

	fileContent, err := os.ReadFile(filename)
	assert.NoError(t, err)

	assert.Len(t, fileContent, size)

	assert.Equal(t, content, fileContent[0:len(content)])
}
